@@ -29,14 +29,14 @@ class TestGroup(TestCase):
         super(TestGroup, self).setUp()
 
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_data(self, mock_open, mock_yaml):
         grp = Group('/tmp/foo')
         data = grp.get_data
         self.assertEqual(data, fakes.GROUP)
 
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_formated_group(self, mock_open, mock_yaml):
         grp = Group('/tmp/foo')
         ret = [('no-op', 'noop-foo'), ('post', 'post-foo'), ('pre', 'pre-foo')]
@@ -44,14 +44,14 @@ class TestGroup(TestCase):
         self.assertEqual(data, ret)
 
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_groups_keys_list(self, mock_open, mock_yaml):
         grp = Group('/tmp/foo')
         ret = ['no-op', 'post', 'pre']
         data = grp.get_groups_keys_list
         self.assertEqual(data, ret)
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_group_file_not_found(self, mock_open):
         mock_open.side_effect = IOError()
         self.assertRaises(
