@@ -43,7 +43,7 @@ class TestUtils(TestCase):
 
     @mock.patch('validations_libs.validation.Validation._get_content',
                 return_value=fakes.FAKE_PLAYBOOK[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists', return_value=True)
     def test_get_validations_data(self, mock_exists, mock_open, mock_data):
         output = {'Name': 'Advanced Format 512e Support',
@@ -58,7 +58,7 @@ class TestUtils(TestCase):
 
     @mock.patch('validations_libs.validation.Validation._get_content',
                 return_value=fakes.FAKE_PLAYBOOK[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists', side_effect=(False, True))
     def test_get_community_validations_data(self, mock_exists, mock_open, mock_data):
         """
@@ -79,7 +79,7 @@ class TestUtils(TestCase):
 
     @mock.patch('validations_libs.validation.Validation._get_content',
                 return_value=fakes.FAKE_PLAYBOOK[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('os.path.exists', side_effect=(False, True))
     def test_get_community_disabled_validations_data(self, mock_exists, mock_open, mock_data):
         """
@@ -101,7 +101,7 @@ class TestUtils(TestCase):
                           validation)
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('glob.glob')
     def test_parse_all_validations_on_disk(self, mock_glob, mock_open,
                                            mock_load):
@@ -111,7 +111,7 @@ class TestUtils(TestCase):
         self.assertEqual(result, [fakes.FAKE_METADATA])
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('glob.glob')
     def test_parse_community_validations_on_disk(
                 self, mock_glob, mock_open, mock_load):
@@ -121,7 +121,7 @@ class TestUtils(TestCase):
         self.assertEqual(result, [fakes.FAKE_METADATA])
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('glob.glob')
     def test_parse_all_community_disabled_validations_on_disk(
                 self, mock_glob, mock_open, mock_load):
@@ -180,7 +180,7 @@ class TestUtils(TestCase):
                           products='foo1,foo2')
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('glob.glob')
     def test_parse_all_validations_on_disk_by_group(self, mock_glob,
                                                     mock_open,
@@ -192,7 +192,7 @@ class TestUtils(TestCase):
         self.assertEqual(result, [fakes.FAKE_METADATA])
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('glob.glob')
     def test_parse_all_validations_on_disk_by_category(self, mock_glob,
                                                        mock_open,
@@ -209,7 +209,7 @@ class TestUtils(TestCase):
                           path=['/foo/playbook'])
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     @mock.patch('glob.glob')
     def test_parse_all_validations_on_disk_by_product(self, mock_glob,
                                                       mock_open,
@@ -222,7 +222,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_playbook_by_id(self, mock_open, mock_load,
                                             mock_glob, mock_isfile):
         mock_glob.side_effect = (['/foo/playbook/foo.yaml'], [])
@@ -234,7 +234,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_community_playbook_by_id(self, mock_open, mock_load,
                                           mock_glob, mock_isfile):
         mock_glob.side_effect = (
@@ -251,7 +251,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_community_disabled_playbook_by_id(
                 self, mock_open, mock_load, mock_glob, mock_isfile):
         mock_glob.side_effect = (
@@ -269,7 +269,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_community_playbook_by_id_not_found(
                 self, mock_open, mock_load, mock_glob, mock_isfile):
         mock_glob.side_effect = (
@@ -284,7 +284,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_playbook_by_id_group(self, mock_open, mock_load,
                                                   mock_glob, mock_isfile):
         mock_glob.side_effect = (['/foo/playbook/foo.yaml'], [])
@@ -296,7 +296,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('os.listdir')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_playbook_group_not_exist(self, mock_open,
                                                       mock_load,
                                                       mock_listdir,
@@ -310,7 +310,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_playbook_by_category(self, mock_open, mock_load,
                                                   mock_glob, mock_isfile):
         mock_glob.side_effect = (['/foo/playbook/foo.yaml'], [])
@@ -322,7 +322,7 @@ class TestUtils(TestCase):
     @mock.patch('os.path.isfile')
     @mock.patch('glob.glob')
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_playbook_by_product(self, mock_open, mock_load,
                                                  mock_glob, mock_isfile):
         mock_glob.side_effect = (['/foo/playbook/foo.yaml'], [])
@@ -332,14 +332,14 @@ class TestUtils(TestCase):
         self.assertEqual(result, ['/foo/playbook/foo.yaml'])
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validation_parameters(self, mock_open, mock_load):
 
         result = utils.get_validation_parameters('/foo/playbook/foo.yaml')
         self.assertEqual(result, {})
 
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_read_validation_groups_file(self, mock_open, mock_load):
 
         result = utils.read_validation_groups_file('/foo/groups.yaml')
@@ -348,7 +348,7 @@ class TestUtils(TestCase):
                                   'pre': [{'description': 'pre-foo'}]})
 
     @mock.patch('yaml.safe_load', return_value=fakes.GROUP)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validation_group_name_list(self, mock_open, mock_load):
 
         result = utils.get_validation_group_name_list('/foo/groups.yaml')
@@ -374,7 +374,7 @@ class TestUtils(TestCase):
                           groups='group1,group2')
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK2)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_parameters_no_group(self, mock_open, mock_load):
 
         result = utils.get_validations_parameters(['/foo/playbook/foo.yaml'],
@@ -383,7 +383,7 @@ class TestUtils(TestCase):
         self.assertEqual(result, output)
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK2)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_parameters_no_val(self, mock_open, mock_load):
 
         result = utils.get_validations_parameters(['/foo/playbook/foo.yaml'],
@@ -392,7 +392,7 @@ class TestUtils(TestCase):
         self.assertEqual(result, output)
 
     @mock.patch('yaml.safe_load', return_value=fakes.FAKE_PLAYBOOK)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validations_parameters_nothing(self, mock_open, mock_load):
 
         result = utils.get_validations_parameters(['/foo/playbook/foo.yaml'],
