@@ -29,7 +29,7 @@ class TestValidationLog(TestCase):
         super(TestValidationLog, self).setUp()
 
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_validation_log_file(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -38,7 +38,7 @@ class TestValidationLog(TestCase):
         self.assertEqual(val.datetime, '2020-03-30T13:17:22.447857Z')
 
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_validation_uuid_wo_validation_id(self, mock_open, mock_json):
         with self.assertRaises(Exception) as exc_mgr:
             ValidationLog(uuid='123')
@@ -47,7 +47,7 @@ class TestValidationLog(TestCase):
                          str(exc_mgr.exception))
 
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_validation_validation_id_wo_uuid(self, mock_open, mock_json):
         with self.assertRaises(Exception) as exc_mgr:
             ValidationLog(validation_id='foo')
@@ -56,7 +56,7 @@ class TestValidationLog(TestCase):
                          str(exc_mgr.exception))
 
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_validation_underscore_validation_id(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_bar_2020-03-30T13:17:22.447857Z.json')
@@ -65,7 +65,7 @@ class TestValidationLog(TestCase):
         self.assertEqual(val.datetime, '2020-03-30T13:17:22.447857Z')
 
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_validation_wrong_log_file(self, mock_open, mock_json):
         msg = ('Wrong log file format, it should be formed '
                'such as {uuid}_{validation-id}_{timestamp}')
@@ -77,7 +77,7 @@ class TestValidationLog(TestCase):
     @mock.patch('glob.glob')
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_log_path(self, mock_open, mock_yaml, mock_glob):
         mock_glob.return_value = \
             ['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json']
@@ -88,7 +88,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('glob.glob')
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_logfile_infos(self, mock_open, mock_json, mock_glob):
         mock_glob.return_value = \
             ['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json']
@@ -99,7 +99,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('glob.glob')
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_logfile_datetime(self, mock_open, mock_json, mock_glob):
         mock_glob.return_value = \
             ['/tmp/123_foo_2020-03-30T13:17:22.447857Z.json']
@@ -108,7 +108,7 @@ class TestValidationLog(TestCase):
         self.assertEqual(datetime, '2020-03-30T13:17:22.447857Z')
 
     @mock.patch('json.load', return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST)
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_logfile_content(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -117,7 +117,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_uuid(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -127,7 +127,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_validation_id(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -137,7 +137,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_status(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -146,7 +146,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.FAILED_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_status_failed(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -155,7 +155,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.BAD_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_status_unreachable(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -164,7 +164,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_host_group(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -173,7 +173,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_hosts_status(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -182,7 +182,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.FAILED_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_hosts_status_failed(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -191,7 +191,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.BAD_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_hosts_status_unreachable(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -200,7 +200,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_unreachable_hosts(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -209,7 +209,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.BAD_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_unreachable_hosts_bad_data(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -218,7 +218,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_duration(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -227,7 +227,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.BAD_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_duration_bad_data(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -236,7 +236,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_start_time(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -245,14 +245,14 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.BAD_VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_start_time_bad_data(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
         start_time = val.get_start_time
         self.assertEqual(start_time, '')
 
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_log_not_found(self, mock_open):
         mock_open.side_effect = IOError()
         self.assertRaises(
@@ -269,7 +269,7 @@ class TestValidationLog(TestCase):
         )
 
     @mock.patch('json.load')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_log_bad_json(self, mock_open, mock_json):
         mock_json.side_effect = ValueError()
         self.assertRaises(
@@ -280,7 +280,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_is_valid_format(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -288,7 +288,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_plays(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
@@ -299,7 +299,7 @@ class TestValidationLog(TestCase):
 
     @mock.patch('json.load',
                 return_value=fakes.VALIDATIONS_LOGS_CONTENTS_LIST[0])
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_get_tasks_data(self, mock_open, mock_json):
         val = ValidationLog(
             logfile='/tmp/123_foo_2020-03-30T13:17:22.447857Z.json')
